//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
// SOFTWARE. 

#ifndef WSCBLINK_H
#define WSCBLINK_H

#include <WScom.h>
#include <WSClistData.h>

class WSCbase;

#define WS_FORE       0
#define WS_BACK       1
#define WS_BOTH       2

class WSCblink{

  protected:
    long         _timer_id;
    WSClistData  _blink_clients;
    WSClistData  _blink_rates;
    WSClistData  _blink_refreshes;
    long         _clock;

    WSDLEX32 static void  _blink_proc(unsigned char,void*);
  public:
    WSDLEX32 WSCblink();
    WSDLEX32 virtual ~WSCblink();
    WSDLEX32 long addBlinkInstance(WSCbase* ,unsigned char rate,WSCbool refresh);
    WSDLEX32 long delBlinkInstance(WSCbase* );
    WSDLEX32 WSCbool getBlinkFore(long rate);
    WSDLEX32 WSClistData* getBlinkClients();
};
extern WSDLEX WSCblink* WSGIappBlink();
#endif
